@@ -1,10 +1,11 @@
 <?php
-// $Id: panels-threecol-25-50-25.tpl.php,v 1.1.2.1 2008/12/16 21:27:58 merlinofchaos Exp $
+// $Id: panels-threecol-33-34-33.tpl.php,v 1.1.2.2 2009/04/30 20:41:45 merlinofchaos Exp $
 /**
  * @file
- * Template for the 1 column panel layout.
+ * Template for a 3 column panel layout.
  *
- * This template provides a three column 25%-50%-25% panel display layout.
+ * This template provides a three column panel display layout, with
+ * each column roughly equal in width.
  *
  * Variables:
  * - $id: An optional CSS id to use for the layout.
@@ -15,7 +16,8 @@
  *   - $content['right']: Content in the right column.
  */
 ?>
-<div class="panel-display panel-3col clear-block" <?php if (!empty($css_id)) { print "id=\"$css_id\""; } ?>>
+
+<div class="panel-display panel-3col-33 clear-block" <?php if (!empty($css_id)) { print "id=\"$css_id\""; } ?>>
   <div class="panel-panel panel-col-first">
     <div class="inside"><?php print $content['left']; ?></div>
   </div>
