@@ -1,5 +1,5 @@
 <?php
-// $Id: panels-twocol-stacked.tpl.php,v 1.1.2.1 2008/12/16 21:27:59 merlinofchaos Exp $
+// $Id: panels-twocol-stacked.tpl.php,v 1.1.2.2 2010/07/20 19:06:04 merlinofchaos Exp $
 /**
  * @file
  * Template for a 2 column panel layout.
@@ -18,19 +18,24 @@
  */
 ?>
 <div class="panel-2col-stacked clear-block panel-display" <?php if (!empty($css_id)) { print "id=\"$css_id\""; } ?>>
-  <div class="panel-col-top panel-panel">
-    <div class="inside"><?php print $content['top']; ?></div>
-  </div>
+  <?php if ($content['top']): ?>
+    <div class="panel-col-top panel-panel">
+      <div class="inside"><?php print $content['top']; ?></div>
+    </div>    
+  <?php endif; ?>
+
   <div class="center-wrapper">
     <div class="panel-col-first panel-panel">
       <div class="inside"><?php print $content['left']; ?></div>
     </div>
-
     <div class="panel-col-last panel-panel">
       <div class="inside"><?php print $content['right']; ?></div>
     </div>
   </div>
-  <div class="panel-col-bottom panel-panel">
-    <div class="inside"><?php print $content['bottom']; ?></div>
-  </div>
+
+  <?php if ($content['bottom']): ?>
+    <div class="panel-col-bottom panel-panel">
+      <div class="inside"><?php print $content['bottom']; ?></div>
+    </div>    
+  <?php endif; ?>
 </div>
